@@ -75,7 +75,6 @@ class SVMONReport:
 
         else:
             self.service_names = services.get_service_name(self.service_type)
-
             b2handle_config= {}
             if self.service_type == 'b2handle' or self.service_type == "B2HANDLE":
                 cwd = os.path.dirname(services.__file__)
@@ -93,10 +92,28 @@ class SVMONReport:
                     else:
                         print("No configuration for b2handle, please see svmon help")
                         exit(1)
+
+            if self.service_type == 'svmon' or self.service_type == "SVMON":
+                svmon_config= {}
+                cwd = os.path.dirname(services.__file__)
+                filename = cwd + "/config.json"
+                readok = os.access(filename, os.R_OK)
+                if readok == False:
+                    print("You have no access to config file: config.json")
+                    exit(-1)
+                with open(filename, 'r') as f:
+                    load_dict= json.load(f)
+                    if 'svmon_app_path' in load_dict:
+                        if  load_dict.get('svmon_app_path') != None and load_dict.get('svmon_app_path') != '':
+                            svmon_config['svmon_app_path'] = load_dict.get('svmon_app_path')
+                        self.tags = services.get_service_tag(self.service_type,svmon_config)
+                        self.service_names = services.get_service_name(self.service_type)
+                    else:
+                        print("No configuration for svmon, please see svmon help")
+                        exit(1)
             else:
                 self.tags = services.get_service_tag(self.service_type)
 
-
     def get_site(self):
         return self.site
 
@@ -140,7 +157,6 @@ class SVMONReport:
         this.service_names.append(service_name)
         this.tags.append(tag)
 
-
     def print_report(self):
         if len(self.service_names) > 0:
             res=[]
@@ -150,19 +166,17 @@ class SVMONReport:
             if  self.tags == None or len(self.tags) < 1:
                 print("no service component version is resolved at your host")
                 exit(1)
-            j=0
-            for i in range(len(self.service_names)):
-                if j < len(self.tags) and self.tags[j] != None and self.tags[j] != "" :
-                    res.append(self.site+'\t'+self.host+'\t'+self.operating_system+'\t'+self.service_type+'\t'+self.service_names[i]+'\t'+self.tags[j]+'\n')
-                    j = j +1
-                    #print(self.service_names[i])
+
+            serviceVersionIterator=0
+            for serviceIterator in range(len(self.service_names)):
+                if serviceVersionIterator < len(self.tags) and self.tags[serviceVersionIterator] != None and self.tags[serviceVersionIterator] != "" :
+                    res.append(self.site+'\t'+self.host+'\t'+self.operating_system+'\t'+self.service_type+'\t'+self.service_names[serviceIterator]+'\t'+self.tags[serviceVersionIterator]+'\n')
+                    serviceVersionIterator = serviceVersionIterator +1
             return res
         else:
             print("Zero service components")
             return []
 
-
-
     def jsonify(self):
         if len(self.service_names) > 0:
             res = {}
@@ -195,6 +209,35 @@ class SVMONReport:
         if handle_server_path != "":
             res['handle_server_path'] = handle_server_path
 
+        cwd = os.path.dirname(services.__file__)
+        filename = cwd + "/config.json"
+        writeok = os.access(filename, os.W_OK)
+        if writeok == False:
+            print("You have no access to write config file: config.json")
+            exit(-1)
+        success = json_operations.save_to_file(filename,res)
+        if success == False:
+            print("Save json data failed")
+            exit(1)
+        else:
+            print("Saved B2HANDLE configuration")
+
+    def save_svmon_app_path(self,svmon_app_path=None):
+        if svmon_app_path == None :
+            print("No svmon_app_path configuration input")
+            exit(-1)
+        if svmon_app_path != None and isinstance(svmon_app_path,str) == False:
+            print("Svmon path should be a string")
+            exit(-1)
+        if  svmon_app_path == "":
+            print("No input for svmon_app_path")
+            exit(-1)
+
+        res={}
+        res['site']= self.site
+        res['host'] = self.host
+        res['service_type'] = self.service_type
+        res['svmon_app_path'] = svmon_app_path
 
         cwd = os.path.dirname(services.__file__)
         filename = cwd + "/config.json"
@@ -207,9 +250,7 @@ class SVMONReport:
             print("Save json data failed")
             exit(1)
         else:
-            print("Saved B2HANLE configuration")
-
-
+            print("Saved SVMON configuration")
 
     def save_to_json(self):
         if self.site != "" and self.site != None:
@@ -217,7 +258,7 @@ class SVMONReport:
             res['site']= self.site
             res['host'] = self.host
             res['service_type'] = self.service_type
-            if self.service_type == "b2hanle" or self.service_type == "B2HANDLE":
+            if self.service_type == "b2handle" or self.service_type == "B2HANDLE":
                 cwd = os.path.dirname(services.__file__)
                 filename = cwd + "/config.json"
                 with open(filename, 'r') as f:
@@ -242,8 +283,6 @@ class SVMONReport:
             print("No services to be jsonified")
             exit(1)
 
-
-
     def save_with_components_to_json(self,specified_components, specified_versions):
 
         if specified_components== None or specified_versions == None and len(specified_versions) == 0 \
@@ -275,9 +314,6 @@ class SVMONReport:
             print("Successfully saved component data")
             exit(1)
 
-
-
-
     def set_pair(self,key,value):
         if isinstance(key,str) == False:
             print("Key should be a string")
@@ -296,14 +332,12 @@ class SVMONReport:
         elif key == "tags":
             self.set_tags(value)
         else :
-            print("such key is not supporteed: %s\n" %key)
+            print("such key is not supported: %s\n" %key)
             exit(1)
 
-
     def check_site(self):
         return True
 
-
     def check_host(self):
         return True
 
@@ -318,8 +352,6 @@ class SVMONReport:
             print('Please use svmon --site <SITE> --host <HOST> --type <TYPE> --dump to change your configuration')
             print('More details, please see svmon --help')
 
-
-
     def send_report_to_svmon_server(self):
        import requests as re
        print('Sending report to svmon server...')
@@ -403,7 +435,6 @@ class SVMONReport:
        print('Report has been sent successfully.')
        exit(0)
 
-
     def save_token(self,token):
         print('Saving token...')
         if token == "":
@@ -426,8 +457,6 @@ class SVMONReport:
             exit(1)
 
 
-
-
 if __name__=="__main__":
     re=SVMONReport()
     re.save_to_json()
